@@ -40,7 +40,8 @@
 #' @section Stations:
 #' Some services accept querying multiple stations at once, and other only allows one station per query:
 #' \itemize{
-#'   \item{AEMET: One or more stations can be provided in a character vector.}
+#'   \item{AEMET: One or more stations can be provided in a character vector (except for
+#'   monthly and yearly resolutions, as they only accept one station.}
 #'   \item{MeteoCat: One or more stations can be provided in a character vector.}
 #'   \item{MeteoGalicia: One or more stations can be provided in a character vector.}
 #'   \item{Meteoclimatic: Only one station can be provided. Nevertheless, some codes can be used to retrieve
@@ -89,7 +90,7 @@ NULL
 #'
 #' @export
 aemet_options <- function(
-  resolution = c('current_day', 'daily'),
+  resolution = c('current_day', 'daily', 'monthly', 'yearly'),
   start_date = Sys.Date(),
   end_date = start_date,
   stations = NULL,
